@@ -1,5 +1,5 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/calctool.h,v 1.32 2003/04/25 15:27:32 richb Exp $
+/*  $Header: /cvs/gnome/gcalctool/gcalctool/calctool.h,v 1.37 2003/07/08 15:17:08 richb Exp $
  *
  *  Copyright (c) 1987-2003 Sun Microsystems, Inc. All Rights Reserved.
  *           
@@ -46,8 +46,8 @@
 #define UNLINK       (void) unlink
 
 /* Menu bar menu types. */
-enum mb_type { M_ASCII, M_BASIC, M_CONTENTS, M_COPY,  M_FIN,
-               M_PASTE, M_QUIT,  M_REGS,     M_SCI,   M_ZEROES };
+enum mb_type { M_ABOUT, M_ASCII, M_BASIC, M_CONTENTS, M_COPY,  M_FIN,
+               M_PASTE, M_QUIT,  M_REGS,  M_SCI,      M_ZEROES };
 
 enum base_type { BIN, OCT, DEC, HEX };      /* Base definitions. */
 
@@ -311,7 +311,7 @@ struct button *copy_button_info(struct button *);
 char *button_str(int);
 char *convert(char *);
 char *get_resource(enum res_type);
-char *make_number(int *, BOOLEAN);
+char *make_number(int *, int, BOOLEAN, BOOLEAN);
 char *set_bool(int);
 
 unsigned short *get_but_data();
@@ -380,7 +380,8 @@ void read_str(char **, char *);
 void save_pending_values(struct button *);
 void save_resources();
 void set_accuracy_toggle(int);
-void set_display(char *str);
+void set_display(char *);
+void set_error_state(int);
 void set_hyp_item(int);
 void set_ins_key();
 void set_item(enum item_type, int);
